aboutsummaryrefslogtreecommitdiff
path: root/CodeGen/CodeGenTypes.h
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2008-02-06 05:21:55 +0000
committerChris Lattner <sabre@nondot.org>2008-02-06 05:21:55 +0000
commit4581fff8af09a156a9dcc4de62587385c5da9574 (patch)
tree89947f102a89d0e6d35349cda4e31cde4976ed3f /CodeGen/CodeGenTypes.h
parentfc3b8e9c1381d5e6ec361591d649c56a870ff971 (diff)
rename TypeHolderMap to TypeCache, which more aptly describes what it is.
git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@46804 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'CodeGen/CodeGenTypes.h')
-rw-r--r--CodeGen/CodeGenTypes.h16
1 files changed, 7 insertions, 9 deletions
diff --git a/CodeGen/CodeGenTypes.h b/CodeGen/CodeGenTypes.h
index 166d10300b..e68d97b1d7 100644
--- a/CodeGen/CodeGenTypes.h
+++ b/CodeGen/CodeGenTypes.h
@@ -100,11 +100,11 @@ public:
private:
llvm::DenseMap<const FieldDecl *, BitFieldInfo> BitFields;
/// TypeHolderMap - This map keeps cache of llvm::Types (through PATypeHolder)
/// and maps llvm::Types to corresponding clang::Type. llvm::PATypeHolder is
/// used instead of llvm::Type because it allows us to bypass potential
/// dangling type pointers due to type refinement on llvm side.
- llvm::DenseMap<Type *, llvm::PATypeHolder> TypeHolderMap;
+ llvm::DenseMap<Type *, llvm::PATypeHolder> TypeCache;
/// ConvertNewType - Convert type T into a llvm::Type. Do not use this
/// method directly because it does not do any type caching. This method
@@ -119,15 +119,13 @@ public:
TargetInfo &getTarget() const { return Target; }
ASTContext &getContext() const { return Context; }
- /// ConvertType - Convert type T into a llvm::Type. Maintain and use
- /// type cache through TypeHolderMap.
+ /// ConvertType - Convert type T into a llvm::Type.
const llvm::Type *ConvertType(QualType T);
- /// ConvertTypeForMem - Convert type T into a llvm::Type. Maintain and use
- /// type cache through TypeHolderMap. This differs from ConvertType in that
- /// it is used to convert to the memory representation for a type. For
- /// example, the scalar representation for _Bool is i1, but the memory
- /// representation is usually i8 or i32, depending on the target.
+ /// ConvertTypeForMem - Convert type T into a llvm::Type. This differs from
+ /// ConvertType in that it is used to convert to the memory representation for
+ /// a type. For example, the scalar representation for _Bool is i1, but the
+ /// memory representation is usually i8 or i32, depending on the target.
const llvm::Type *ConvertTypeForMem(QualType T);
@@ -100,11 +100,11 @@ public:
private:
llvm::DenseMap<const FieldDecl *, BitFieldInfo> BitFields;
- /// TypeHolderMap - This map keeps cache of llvm::Types (through PATypeHolder)
+ /// TypeCache - This map keeps cache of llvm::Types (through PATypeHolder)
/// and maps llvm::Types to corresponding clang::Type. llvm::PATypeHolder is
/// used instead of llvm::Type because it allows us to bypass potential